/*
  Analog read for PH probe 10 bit.
 
 Reads an analog input pin, ANALOG PIN 0 and sends the data to the serial port.
 
 Protocol:
 The protocol is a three byte data package,
 Header = 0;
 PhHi   = Hi-byte of 10 bit & address (64 addresses max)
 PhLo   = Lo-byte.
 
  The circuit:
 * Connect the PH probe to the AN0 (analog 0) 
 
   created 22 May. 2013
   Martin Hug
 
 */
 
 
// variables declaration:

const int analogInPin = A0; // Analog input pin that the Ph probe is connected.

int sensorValue = 0;        // 10bit value read from the PH probe.
byte address = 4;           // 00000100, first possible address.
byte PhLo = 0;              // Lo-byte of 10 bit data.
byte PhHi = 0;              // Hi-byte of 10 bit data.

void setup() {
  // initialize serial communications at 9600 bps:
  Serial.begin(9600); 
}

void loop() {
  // read the analog in value:
  sensorValue = analogRead(analogInPin);            

  PhHi = address | sensorValue>>8; // merge adddress and upper byte.
  PhLo = sensorValue;              // lower byte. 
  

  // print the results to the serial monitor:
  // Serial.write for DECIMAL format (Pd) , Serial.print for ASCII format (Serial Monitor). 
     
  Serial.write(0);    // header byte.
  Serial.write(PhHi); // first byte. 
  Serial.write(PhLo); // second byte.
  
  delay(25);  // change value for slower data transfer.                   
}

